#
# bug.rb
#
#   Copyright (c) 1999,2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
#
#   This program is free software.
#   You can distribute/modify this program under the terms of
#   the GNU General Public License version 2 or later.
#
# usage:
#
#   if find_bug then
#     bug! "unknown bug found"
#   end
#


class FindBug < StandardError ; end

class Object

  private

  def bug!( message = 'must not happen' )
    raise FindBug, "\n[SCRIPT BUG] " + message
  end

end
